==> openGion6.4.8.0_dev.zip: uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_CMNT_CLM.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

import java.io.File;
import java.io.PrintWriter;
// import java.util.Map;

import org.opengion.fukurou.util.ErrorMessage;
import org.opengion.fukurou.util.FileUtil;
import org.opengion.fukurou.util.FixLengthData;
import org.opengion.fukurou.util.StringUtil;
import org.opengion.hayabusa.common.HybsSystemException;
import org.opengion.hayabusa.db.AbstractTableFilter;
import org.opengion.hayabusa.db.DBTableModel;

/**
 * TableFilter_CMNT_CLM は、TableFilter インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。
 *
 * ここでは、テーブルカラム一覧の検索結果より、ORACLE のテーブルカラムにコメントを作成します。
 * 構文は、「COMMENT ON COLUMN テーブル名.カラム名 IS 'コメント'」です。
 * このコメントを取り出す場合は、
 *「SELECT COLUMN_NAME, COMMENTS FROM USER_COL_COMMENTS WHERE TABLE_NAME = 'テーブル名'」
 * とします。
 * 
 * SQLのツール類には、このコメントを使用して、テーブルカラムの日本語名を表示させたりします。
 * 
 * 検索では、(TABLE_NAME,CLM,NAME_JA) の項目を取得する必要があります。
 *
 * パラメータは、tableFilterタグの keys, vals にそれぞれ記述するか、BODY 部にCSS形式で記述します。
 * 出力ファイル名は、通常、テーブル で１つ、カラムで１つにまとめて作成されます。
 * 【パラメータ】
 *  {
 *       DIR  : {&#064;BASE_DIR}/sql/install/08_CMNT ;    出力ファイルの基準フォルダ(必須)
 *       FILE : false ;                                   出力ファイル名(初期値:CMNT_CLM[.sql|.xml])
 *       XML  : false ;                                   XML出力を行うかどうか[true/false]を指定します(初期値:false)
 *  }
 *
 * @og.formSample
 * ●形式：
 *      select SYSTEM_ID,TABLE_NAME,NAME_JA from GF02
 * 
 *      ① &lt;og:tableFilter classId="CMNT_CLM" keys="DIR" vals='"{&#064;BASE_DIR}/sql/install/08_CMNT"' /&gt;
 *
 *      ② &lt;og:tableFilter classId="CMNT_CLM" &gt;
 *               {
 *                   DIR   : {&#064;BASE_DIR}/sql/install/08_CMNT ;
 *                   FILE  : CMNT_CLM ;
 *                   XML   : false ;
 *               }
 *         &lt;/og:tableFilter&gt;
 *
 * @og.rev 4.0.0.0 (2005/08/31) 新規作成
 *
 * @version  0.9.0  2000/10/17
 * @author   Kazuhiko Hasegawa
 * @since    JDK1.6,
 */
public class TableFilter_CMNT_CLM extends AbstractTableFilter {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.4.1.1 (2016/01/16)" ;

	private static final String[] DBKEY = {"TABLE_NAME","CLM","NAME_JA"};

	/** データのアクセス用の配列番号 {@value} */
	protected static final int TABLE_NAME		= 0;
	/** データのアクセス用の配列番号 {@value} */
	protected static final int CLM				= 1;
	/** データのアクセス用の配列番号 {@value} */
	protected static final int NAME_JA			= 2;

 //	private static final String ENCODE = "Windows-31J" ;
	private static final String ENCODE = "UTF-8" ;

	private static final int X = FixLengthData.X ;		// type 定数
	private static final int K = FixLengthData.K ;		// type 定数

	/** 各種定数  */
	// 6.0.2.3 (2014/10/10) AbstractTableFilter へ移動

	/** XML形式かどうか */

	/** ファイル名(拡張子なし) */
	private String		fileName				= "CMNT_CLM";

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.1.1 (2016/01/16) keysMap を、サブクラスから設定させるように変更。
	 */
	public TableFilter_CMNT_CLM() {
		super();
		initSet( "DIR"	, "出力ファイルの基準フォルダ(必須)"						);
		initSet( "FILE"	, "出力ファイル名(初期値:CMNT_CLM[.sql|.xml])"				);
		initSet( "XML"	, "XML出力を行うかどうか[true/false]を指定(初期値:false)"	);
	}

//	/**
//	 * keys の整合性チェックを行うための初期設定を行います。
//	 *
//	 * @og.rev 5.6.6.1 (2013/07/12) keys の整合性チェック対応
//	 * @og.rev 6.4.1.1 (2016/01/16) keysMap を、サブクラスから設定させるため、廃止。
//	 *
//	 * @param	keysMap keys の整合性チェックを行うための Map
//	 */
//	@Override
//	protected void init( final Map<String,String> keysMap ) {
//		keysMap.put( "DIR"	, "出力ファイルの基準フォルダ(必須)"						);
//		keysMap.put( "FILE"	, "出力ファイル名(初期値:CMNT_CLM[.sql|.xml])"				);
//		keysMap.put( "XML"	, "XML出力を行うかどうか[true/false]を指定(初期値:false)"	);
//	}

	/**
	 * DBTableModel処理を実行します。
	 *
	 * @og.rev 6.0.2.3 (2014/10/10) EXEC_END_TAG を追加。キャッシュします。
	 * @og.rev 6.3.7.0 (2015/09/04) AutoCloseableを使用したtry-with-resources構築に対応。
	 *
	 * @return	実行結果のテーブルモデル
	 */
	public DBTableModel execute() {
//		final DBTableModel table = getDBTableModel();

		isXml   = StringUtil.nval( getValue( "XML"   ), isXml   );
		execEndTag = isXml ? EXEC_END_TAG : ";" ;	// 6.0.2.3 (2014/10/10) CMNTは タグの前に改行を入れない。

		final File dir = new File( getValue( "DIR" ) );

		if( ! dir.exists() && ! dir.mkdirs() ) {
			final String errMsg = "所定のフォルダが作成できませんでした。[" + dir + "]" ;
			// 4.3.4.4 (2009/01/01)
			throw new HybsSystemException( errMsg );
		}

		fileName =  StringUtil.nval( getValue( "FILE" ), fileName );

		// COMMENT ON COLUMN テーブル名.カラム名 IS 'コメント'
		final int[] addLen = new int[] { 0,0,0,0 };	// 各データ間のスペース
		final int[] type   = new int[] { X,X,X,K };	// 各データの種別 X:半角 S:空白前埋め K:全角混在
		final FixLengthData fixData = new FixLengthData( addLen,type );

		String[] data  = null;
		int row = 0;
		// 6.3.7.0 (2015/09/04) AutoCloseableを使用したtry-with-resources構築に対応。
//		try {
//			final PrintWriter writer = FileUtil.getPrintWriter( new File( dir,fileName + ( isXml ? ".xml" : ".sql" ) ),ENCODE );
		// 6.4.1.1 (2016/01/16) PMD refactoring. Avoid declaring a variable if it is unreferenced before a possible exit point.
		final DBTableModel table = getDBTableModel();
		try( final PrintWriter writer = FileUtil.getPrintWriter( new File( dir,fileName + ( isXml ? ".xml" : ".sql" ) ),ENCODE ) ) {

			if( isXml ) { writer.println( XML_START_TAG ); }

			// 全データを読み込んで、最大長の計算を行う。
			final int[] clmNo = getTableColumnNo( DBKEY );
			final int rowCnt = table.getRowCount();
			for( row=0; row<rowCnt; row++ ) {
				data      = table.getValues( row );
				final String tblClm  = data[clmNo[TABLE_NAME]] + "." + data[clmNo[CLM]];
				final String name_ja = "'" + data[clmNo[NAME_JA]] + "'";

				final String[] outData = new String[] { "COMMENT ON COLUMN " , tblClm , " IS " , name_ja } ;
				fixData.addListData( outData );
			}

			// データの出力
			for( row=0; row<rowCnt; row++ ) {
				if( isXml ) { writer.print( EXEC_START_TAG ); }
				writer.print( fixData.getFixData( row ) );
				writer.println( execEndTag );						// 6.0.2.3 (2014/10/10)
			}

			if( isXml ) { writer.println( XML_END_TAG ); }
//			writer.close();
		}
		catch( RuntimeException ex ) {		// catch は、close() されてから呼ばれます。
			final ErrorMessage errMessage = makeErrorMessage( "TableFilter_CMNT_CLM Error",ErrorMessage.NG );
			data = table.getValues( row );
			errMessage.addMessage( row+1,ErrorMessage.NG,"CMNT_CLM",StringUtil.array2csv( data ) );
			// BAT から呼び出す場合があるため、標準エラー出力にも情報を出しておきます。
			System.out.println( errMessage );
			System.out.println( ex );
		}

		return table;
	}
}

==> openGion6.9.9.0_dev.zip: uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_CMNT_CLM.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

import java.io.File;
import java.io.PrintWriter;

import org.opengion.fukurou.util.ErrorMessage;
import org.opengion.fukurou.util.FileUtil;
import org.opengion.fukurou.util.FixLengthData;
import org.opengion.fukurou.util.StringUtil;
import org.opengion.hayabusa.common.HybsSystemException;
import org.opengion.hayabusa.db.AbstractTableFilter;
import org.opengion.hayabusa.db.DBTableModel;

/**
 * TableFilter_CMNT_CLM は、TableFilter インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。
 *
 * ここでは、テーブルカラム一覧の検索結果より、ORACLE のテーブルカラムにコメントを作成します。
 * 構文は、「COMMENT ON COLUMN テーブル名.カラム名 IS 'コメント'」です。
 * このコメントを取り出す場合は、
 *「SELECT COLUMN_NAME, COMMENTS FROM USER_COL_COMMENTS WHERE TABLE_NAME = 'テーブル名'」
 * とします。
 * 
 * SQLのツール類には、このコメントを使用して、テーブルカラムの日本語名を表示させたりします。
 * 
 * 検索では、(TABLE_NAME,CLM,NAME_JA) の項目を取得する必要があります。
 *
 * パラメータは、tableFilterタグの keys, vals にそれぞれ記述するか、BODY 部にCSS形式で記述します。
 * 出力ファイル名は、通常、テーブル で１つ、カラムで１つにまとめて作成されます。
 * 【パラメータ】
 *  {
 *       DIR  : {&#064;BASE_DIR}/sql/install/08_CMNT ;    出力ファイルの基準フォルダ(必須)
 *       FILE : false ;                                   出力ファイル名(初期値:CMNT_CLM[.sql|.xml])
 *       XML  : false ;                                   XML出力を行うかどうか[true/false]を指定します(初期値:false)
 *  }
 *
 * @og.formSample
 * ●形式：
 *      select SYSTEM_ID,TABLE_NAME,NAME_JA from GF02
 * 
 *      ① &lt;og:tableFilter classId="CMNT_CLM" keys="DIR" vals='"{&#064;BASE_DIR}/sql/install/08_CMNT"' /&gt;
 *
 *      ② &lt;og:tableFilter classId="CMNT_CLM" &gt;
 *               {
 *                   DIR   : {&#064;BASE_DIR}/sql/install/08_CMNT ;
 *                   FILE  : CMNT_CLM ;
 *                   XML   : false ;
 *               }
 *         &lt;/og:tableFilter&gt;
 *
 * @og.rev 4.0.0.0 (2005/08/31) 新規作成
 *
 * @version  0.9.0  2000/10/17
 * @author   Kazuhiko Hasegawa
 * @since    JDK1.6,
 */
public class TableFilter_CMNT_CLM extends AbstractTableFilter {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.4.1.1 (2016/01/16)" ;

	private static final String[] DBKEY = {"TABLE_NAME","CLM","NAME_JA"};

	/** データのアクセス用の配列番号 {@value} */
	protected static final int TABLE_NAME		= 0;
	/** データのアクセス用の配列番号 {@value} */
	protected static final int CLM				= 1;
	/** データのアクセス用の配列番号 {@value} */
	protected static final int NAME_JA			= 2;

 //	private static final String ENCODE = "Windows-31J" ;
	private static final String ENCODE = "UTF-8" ;

	private static final int X = FixLengthData.X ;		// type 定数
	private static final int K = FixLengthData.K ;		// type 定数

	/** 各種定数  */
	// 6.0.2.3 (2014/10/10) AbstractTableFilter へ移動

	/** XML形式かどうか */

	/** ファイル名(拡張子なし) */
	private String		fileName				= "CMNT_CLM";

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.1.1 (2016/01/16) keysMap を、サブクラスから設定させるように変更。
	 */
	public TableFilter_CMNT_CLM() {
		super();
		initSet( "DIR"	, "出力ファイルの基準フォルダ(必須)"						);
		initSet( "FILE"	, "出力ファイル名(初期値:CMNT_CLM[.sql|.xml])"				);
		initSet( "XML"	, "XML出力を行うかどうか[true/false]を指定(初期値:false)"	);
	}

	/**
	 * DBTableModel処理を実行します。
	 *
	 * @og.rev 6.0.2.3 (2014/10/10) EXEC_END_TAG を追加。キャッシュします。
	 * @og.rev 6.3.7.0 (2015/09/04) AutoCloseableを使用したtry-with-resources構築に対応。
	 *
	 * @return	実行結果のテーブルモデル
	 */
	public DBTableModel execute() {
		isXml   = StringUtil.nval( getValue( "XML"   ), isXml   );
		execEndTag = isXml ? EXEC_END_TAG : ";" ;	// 6.0.2.3 (2014/10/10) CMNTは タグの前に改行を入れない。

		final File dir = new File( getValue( "DIR" ) );

		if( ! dir.exists() && ! dir.mkdirs() ) {
			final String errMsg = "所定のフォルダが作成できませんでした。[" + dir + "]" ;
			// 4.3.4.4 (2009/01/01)
			throw new HybsSystemException( errMsg );
		}

		fileName =  StringUtil.nval( getValue( "FILE" ), fileName );

		// COMMENT ON COLUMN テーブル名.カラム名 IS 'コメント'
		final int[] addLen = new int[] { 0,0,0,0 };	// 各データ間のスペース
		final int[] type   = new int[] { X,X,X,K };	// 各データの種別 X:半角 S:空白前埋め K:全角混在
		final FixLengthData fixData = new FixLengthData( addLen,type );

		String[] data  = null;
		int row = 0;
		// 6.3.7.0 (2015/09/04) AutoCloseableを使用したtry-with-resources構築に対応。
		// 6.4.1.1 (2016/01/16) PMD refactoring. Avoid declaring a variable if it is unreferenced before a possible exit point.
		final DBTableModel table = getDBTableModel();
		try( final PrintWriter writer = FileUtil.getPrintWriter( new File( dir,fileName + ( isXml ? ".xml" : ".sql" ) ),ENCODE ) ) {

			if( isXml ) { writer.println( XML_START_TAG ); }

			// 全データを読み込んで、最大長の計算を行う。
			final int[] clmNo = getTableColumnNo( DBKEY );
			final int rowCnt = table.getRowCount();
			for( row=0; row<rowCnt; row++ ) {
				data      = table.getValues( row );
				final String tblClm  = data[clmNo[TABLE_NAME]] + "." + data[clmNo[CLM]];
				final String name_ja = "'" + data[clmNo[NAME_JA]] + "'";

				final String[] outData = new String[] { "COMMENT ON COLUMN " , tblClm , " IS " , name_ja } ;
				fixData.addListData( outData );
			}

			// データの出力
			for( row=0; row<rowCnt; row++ ) {
				if( isXml ) { writer.print( EXEC_START_TAG ); }
				writer.print( fixData.getFixData( row ) );
				writer.println( execEndTag );						// 6.0.2.3 (2014/10/10)
			}

			if( isXml ) { writer.println( XML_END_TAG ); }
		}
		catch( final RuntimeException ex ) {		// catch は、close() されてから呼ばれます。
			final ErrorMessage errMessage = makeErrorMessage( "TableFilter_CMNT_CLM Error",ErrorMessage.NG );
			data = table.getValues( row );
			errMessage.addMessage( row+1,ErrorMessage.NG,"CMNT_CLM",StringUtil.array2csv( data ) );
			// BAT から呼び出す場合があるため、標準エラー出力にも情報を出しておきます。
			System.out.println( errMessage );
			System.out.println( ex );
		}

		return table;
	}
}
